from .price import price
from .trade import trade
from .API import API


__title__ = "SIGMATMPY"
__version__ = "0.0.3"
__author__ = "YOU WU"
__license__ = "MIT"
__copyright__ = "Copyright (c) 2021 BFJFunds"

# Version synonym
VERSION = __version__
